@@ -1,3 +1,5 @@
+( cd opt/kde/share/doc/HTML/ru/ark ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ark ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/ktuberling ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ktuberling ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kmix ; rm -rf common )
@@ -16,16 +18,12 @@
 ( cd opt/kde/share/doc/HTML/ru/kbattleship ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kfloppy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kfloppy ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
-( cd opt/kde/share/doc/HTML/ru/clock ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ru/clock ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kandy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kandy ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kwin4 ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kwin4 ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/lskat ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
-( cd opt/kde/share/doc/HTML/ru/kmixcfg ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ru/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/khelpcenter/faq ; rm -rf common )
@@ -136,14 +134,18 @@
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
-( cd opt/kde/share/doc/HTML/ru/kcmlaunch ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ru/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/arts ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/clock ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/mouse ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kmixcfg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlaunch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/useragent ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/keyboard ; rm -rf common )
@@ -152,6 +154,10 @@
 ( cd opt/kde/share/doc/HTML/ru/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/crashes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/babel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kbabel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kbabel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kicker ; rm -rf common )
